| Copyright | (c) Julian Ospald 2020 |
|---|---|
| License | LGPL-3.0 |
| Maintainer | hasufell@hasufell.de |
| Stability | experimental |
| Portability | portable |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
GHCup.Errors
Contents
Description
Synopsis
- allHFError :: String
- prettyHFError :: (Pretty e, HFErrorProject e) => e -> String
- class HFErrorProject a where
- linkEscapeCode :: String -> String -> String
- data NoCompatiblePlatform = NoCompatiblePlatform String
- data NoDownload = NoDownload GHCTargetVersion Tool (Maybe PlatformRequest)
- data NoUpdate = NoUpdate
- data NoCompatibleArch = NoCompatibleArch String
- data DistroNotFound = DistroNotFound
- data UnknownArchive = UnknownArchive FilePath
- data UnsupportedScheme = UnsupportedScheme
- data CopyError = CopyError String
- data MergeFileTreeError = MergeFileTreeError IOException FilePath FilePath
- data TagNotFound = TagNotFound Tag Tool
- data DayNotFound = DayNotFound Day Tool (Maybe Day)
- data NextVerNotFound = NextVerNotFound Tool
- data AlreadyInstalled = AlreadyInstalled Tool Version
- data DirNotEmpty = DirNotEmpty {}
- data NotInstalled = NotInstalled Tool GHCTargetVersion
- data UninstallFailed = UninstallFailed FilePath [FilePath]
- data NotFoundInPATH = NotFoundInPATH FilePath
- data JSONError = JSONDecodeError String
- data FileDoesNotExistError = FileDoesNotExistError FilePath
- data FileAlreadyExistsError = FileAlreadyExistsError FilePath
- data TarDirDoesNotExist = TarDirDoesNotExist TarDir
- data DigestError = DigestError FilePath Text Text
- data GPGError = forall xs.(ToVariantMaybe DownloadFailed xs, PopVariant DownloadFailed xs, Show (V xs), Pretty (V xs)) => GPGError (V xs)
- data HTTPStatusError = HTTPStatusError Int (Map (CI ByteString) ByteString)
- data MalformedHeaders = MalformedHeaders Text
- data HTTPNotModified = HTTPNotModified Text
- data NoLocationHeader = NoLocationHeader
- data TooManyRedirs = TooManyRedirs
- data PatchFailed = PatchFailed
- data NoToolRequirements = NoToolRequirements
- data InvalidBuildConfig = InvalidBuildConfig Text
- data NoToolVersionSet = NoToolVersionSet Tool
- data NoNetwork = NoNetwork
- data HadrianNotFound = HadrianNotFound
- data ToolShadowed = ToolShadowed Tool FilePath FilePath Version
- data ContentLengthError = ContentLengthError (Maybe FilePath) (Maybe Integer) Integer
- data DuplicateReleaseChannel = DuplicateReleaseChannel NewURLSource
- data UnsupportedSetupCombo = UnsupportedSetupCombo Architecture Platform
- data DownloadFailed = forall xs.(HFErrorProject (V xs), ToVariantMaybe DownloadFailed xs, PopVariant DownloadFailed xs, Show (V xs), Pretty (V xs)) => DownloadFailed (V xs)
- data InstallSetError = forall xs1 xs2.(Show (V xs1), Pretty (V xs1), HFErrorProject (V xs1), Show (V xs2), Pretty (V xs2), HFErrorProject (V xs2)) => InstallSetError (V xs1) (V xs2)
- data TestFailed = forall es.(ToVariantMaybe TestFailed es, PopVariant TestFailed es, Pretty (V es), Show (V es), HFErrorProject (V es)) => TestFailed FilePath (V es)
- data BuildFailed = forall es.(ToVariantMaybe BuildFailed es, PopVariant BuildFailed es, Pretty (V es), Show (V es), HFErrorProject (V es)) => BuildFailed FilePath (V es)
- data GHCupSetError = forall es.(ToVariantMaybe GHCupSetError es, PopVariant GHCupSetError es, Show (V es), Pretty (V es), HFErrorProject (V es)) => GHCupSetError (V es)
- data StackPlatformDetectError = forall es.(ToVariantMaybe StackPlatformDetectError es, PopVariant StackPlatformDetectError es, Show (V es), Pretty (V es), HFErrorProject (V es)) => StackPlatformDetectError (V es)
- data ParseError = ParseError String
- data UnexpectedListLength = UnexpectedListLength String
- data NoUrlBase = NoUrlBase Text
- data DigestMissing = DigestMissing URI
Documentation
allHFError :: String Source #
prettyHFError :: (Pretty e, HFErrorProject e) => e -> String Source #
class HFErrorProject a where Source #
Instances
data NoCompatiblePlatform Source #
A compatible platform could not be found.
Constructors
| NoCompatiblePlatform String |
Instances
| Show NoCompatiblePlatform Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> NoCompatiblePlatform -> ShowS # show :: NoCompatiblePlatform -> String # showList :: [NoCompatiblePlatform] -> ShowS # | |
| HFErrorProject NoCompatiblePlatform Source # | |
Defined in GHCup.Errors | |
| Pretty NoCompatiblePlatform Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> NoCompatiblePlatform -> Doc # pPrint :: NoCompatiblePlatform -> Doc # pPrintList :: PrettyLevel -> [NoCompatiblePlatform] -> Doc # | |
data NoDownload Source #
Unable to find a download for the requested version/distro.
Constructors
| NoDownload GHCTargetVersion Tool (Maybe PlatformRequest) |
Instances
| Show NoDownload Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> NoDownload -> ShowS # show :: NoDownload -> String # showList :: [NoDownload] -> ShowS # | |
| HFErrorProject NoDownload Source # | |
Defined in GHCup.Errors | |
| Pretty NoDownload Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> NoDownload -> Doc # pPrint :: NoDownload -> Doc # pPrintList :: PrettyLevel -> [NoDownload] -> Doc # | |
No update available or necessary.
Constructors
| NoUpdate |
Instances
| Show NoUpdate Source # | |
| HFErrorProject NoUpdate Source # | |
| Pretty NoUpdate Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> NoUpdate -> Doc # pPrintList :: PrettyLevel -> [NoUpdate] -> Doc # | |
data NoCompatibleArch Source #
The Architecture is unknown and unsupported.
Constructors
| NoCompatibleArch String |
Instances
| Show NoCompatibleArch Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> NoCompatibleArch -> ShowS # show :: NoCompatibleArch -> String # showList :: [NoCompatibleArch] -> ShowS # | |
| HFErrorProject NoCompatibleArch Source # | |
Defined in GHCup.Errors | |
| Pretty NoCompatibleArch Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> NoCompatibleArch -> Doc # pPrint :: NoCompatibleArch -> Doc # pPrintList :: PrettyLevel -> [NoCompatibleArch] -> Doc # | |
data DistroNotFound Source #
Unable to figure out the distribution of the host.
Constructors
| DistroNotFound |
Instances
| Show DistroNotFound Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> DistroNotFound -> ShowS # show :: DistroNotFound -> String # showList :: [DistroNotFound] -> ShowS # | |
| HFErrorProject DistroNotFound Source # | |
Defined in GHCup.Errors | |
| Pretty DistroNotFound Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> DistroNotFound -> Doc # pPrint :: DistroNotFound -> Doc # pPrintList :: PrettyLevel -> [DistroNotFound] -> Doc # | |
data UnknownArchive Source #
The archive format is unknown. We don't know how to extract it.
Constructors
| UnknownArchive FilePath |
Instances
| Show UnknownArchive Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> UnknownArchive -> ShowS # show :: UnknownArchive -> String # showList :: [UnknownArchive] -> ShowS # | |
| HFErrorProject UnknownArchive Source # | |
Defined in GHCup.Errors | |
| Pretty UnknownArchive Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> UnknownArchive -> Doc # pPrint :: UnknownArchive -> Doc # pPrintList :: PrettyLevel -> [UnknownArchive] -> Doc # | |
data UnsupportedScheme Source #
The scheme is not supported (such as ftp).
Constructors
| UnsupportedScheme |
Instances
| Show UnsupportedScheme Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> UnsupportedScheme -> ShowS # show :: UnsupportedScheme -> String # showList :: [UnsupportedScheme] -> ShowS # | |
| HFErrorProject UnsupportedScheme Source # | |
Defined in GHCup.Errors | |
| Pretty UnsupportedScheme Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> UnsupportedScheme -> Doc # pPrint :: UnsupportedScheme -> Doc # pPrintList :: PrettyLevel -> [UnsupportedScheme] -> Doc # | |
Unable to copy a file.
Instances
| Show CopyError Source # | |
| HFErrorProject CopyError Source # | |
| Pretty CopyError Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> CopyError -> Doc # pPrintList :: PrettyLevel -> [CopyError] -> Doc # | |
data MergeFileTreeError Source #
Unable to merge file trees.
Constructors
| MergeFileTreeError IOException FilePath FilePath |
Instances
| Show MergeFileTreeError Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> MergeFileTreeError -> ShowS # show :: MergeFileTreeError -> String # showList :: [MergeFileTreeError] -> ShowS # | |
| HFErrorProject MergeFileTreeError Source # | |
Defined in GHCup.Errors | |
| Pretty MergeFileTreeError Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> MergeFileTreeError -> Doc # pPrint :: MergeFileTreeError -> Doc # pPrintList :: PrettyLevel -> [MergeFileTreeError] -> Doc # | |
data TagNotFound Source #
Unable to find a tag of a tool.
Constructors
| TagNotFound Tag Tool |
Instances
| Show TagNotFound Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> TagNotFound -> ShowS # show :: TagNotFound -> String # showList :: [TagNotFound] -> ShowS # | |
| HFErrorProject TagNotFound Source # | |
Defined in GHCup.Errors | |
| Pretty TagNotFound Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> TagNotFound -> Doc # pPrint :: TagNotFound -> Doc # pPrintList :: PrettyLevel -> [TagNotFound] -> Doc # | |
data DayNotFound Source #
Unable to find a release day of a tool
Constructors
| DayNotFound Day Tool (Maybe Day) |
Instances
| Show DayNotFound Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> DayNotFound -> ShowS # show :: DayNotFound -> String # showList :: [DayNotFound] -> ShowS # | |
| HFErrorProject DayNotFound Source # | |
Defined in GHCup.Errors | |
| Pretty DayNotFound Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> DayNotFound -> Doc # pPrint :: DayNotFound -> Doc # pPrintList :: PrettyLevel -> [DayNotFound] -> Doc # | |
data NextVerNotFound Source #
Unable to find the next version of a tool (the one after the currently set one).
Constructors
| NextVerNotFound Tool |
Instances
| Show NextVerNotFound Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> NextVerNotFound -> ShowS # show :: NextVerNotFound -> String # showList :: [NextVerNotFound] -> ShowS # | |
| HFErrorProject NextVerNotFound Source # | |
Defined in GHCup.Errors | |
| Pretty NextVerNotFound Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> NextVerNotFound -> Doc # pPrint :: NextVerNotFound -> Doc # pPrintList :: PrettyLevel -> [NextVerNotFound] -> Doc # | |
data AlreadyInstalled Source #
The tool (such as GHC) is already installed with that version.
Constructors
| AlreadyInstalled Tool Version |
Instances
| Show AlreadyInstalled Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> AlreadyInstalled -> ShowS # show :: AlreadyInstalled -> String # showList :: [AlreadyInstalled] -> ShowS # | |
| HFErrorProject AlreadyInstalled Source # | |
Defined in GHCup.Errors | |
| Pretty AlreadyInstalled Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> AlreadyInstalled -> Doc # pPrint :: AlreadyInstalled -> Doc # pPrintList :: PrettyLevel -> [AlreadyInstalled] -> Doc # | |
data DirNotEmpty Source #
The Directory is supposed to be empty, but wasn't.
Constructors
| DirNotEmpty | |
Instances
| Show DirNotEmpty Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> DirNotEmpty -> ShowS # show :: DirNotEmpty -> String # showList :: [DirNotEmpty] -> ShowS # | |
| HFErrorProject DirNotEmpty Source # | |
Defined in GHCup.Errors | |
| Pretty DirNotEmpty Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> DirNotEmpty -> Doc # pPrint :: DirNotEmpty -> Doc # pPrintList :: PrettyLevel -> [DirNotEmpty] -> Doc # | |
data NotInstalled Source #
The tool is not installed. Some operations rely on a tool to be installed (such as setting the current GHC version).
Constructors
| NotInstalled Tool GHCTargetVersion |
Instances
| Show NotInstalled Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> NotInstalled -> ShowS # show :: NotInstalled -> String # showList :: [NotInstalled] -> ShowS # | |
| HFErrorProject NotInstalled Source # | |
Defined in GHCup.Errors | |
| Pretty NotInstalled Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> NotInstalled -> Doc # pPrint :: NotInstalled -> Doc # pPrintList :: PrettyLevel -> [NotInstalled] -> Doc # | |
data UninstallFailed Source #
Constructors
| UninstallFailed FilePath [FilePath] |
Instances
| Show UninstallFailed Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> UninstallFailed -> ShowS # show :: UninstallFailed -> String # showList :: [UninstallFailed] -> ShowS # | |
| HFErrorProject UninstallFailed Source # | |
Defined in GHCup.Errors | |
| Pretty UninstallFailed Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> UninstallFailed -> Doc # pPrint :: UninstallFailed -> Doc # pPrintList :: PrettyLevel -> [UninstallFailed] -> Doc # | |
data NotFoundInPATH Source #
An executable was expected to be in PATH, but was not found.
Constructors
| NotFoundInPATH FilePath |
Instances
| Exception NotFoundInPATH Source # | |
Defined in GHCup.Errors Methods toException :: NotFoundInPATH -> SomeException # | |
| Show NotFoundInPATH Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> NotFoundInPATH -> ShowS # show :: NotFoundInPATH -> String # showList :: [NotFoundInPATH] -> ShowS # | |
| HFErrorProject NotFoundInPATH Source # | |
Defined in GHCup.Errors | |
| Pretty NotFoundInPATH Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> NotFoundInPATH -> Doc # pPrint :: NotFoundInPATH -> Doc # pPrintList :: PrettyLevel -> [NotFoundInPATH] -> Doc # | |
JSON decoding failed.
Constructors
| JSONDecodeError String |
Instances
| Show JSONError Source # | |
| HFErrorProject JSONError Source # | |
| Pretty JSONError Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> JSONError -> Doc # pPrintList :: PrettyLevel -> [JSONError] -> Doc # | |
data FileDoesNotExistError Source #
A file that is supposed to exist does not exist (e.g. when we use file scheme to "download" something).
Constructors
| FileDoesNotExistError FilePath |
Instances
| Show FileDoesNotExistError Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> FileDoesNotExistError -> ShowS # show :: FileDoesNotExistError -> String # showList :: [FileDoesNotExistError] -> ShowS # | |
| HFErrorProject FileDoesNotExistError Source # | |
Defined in GHCup.Errors | |
| Pretty FileDoesNotExistError Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> FileDoesNotExistError -> Doc # pPrint :: FileDoesNotExistError -> Doc # pPrintList :: PrettyLevel -> [FileDoesNotExistError] -> Doc # | |
data FileAlreadyExistsError Source #
The file already exists (e.g. when we use isolated installs with the same path). (e.g. This is done to prevent any overwriting)
Constructors
| FileAlreadyExistsError FilePath |
Instances
| Show FileAlreadyExistsError Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> FileAlreadyExistsError -> ShowS # show :: FileAlreadyExistsError -> String # showList :: [FileAlreadyExistsError] -> ShowS # | |
| HFErrorProject FileAlreadyExistsError Source # | |
Defined in GHCup.Errors | |
| Pretty FileAlreadyExistsError Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> FileAlreadyExistsError -> Doc # pPrint :: FileAlreadyExistsError -> Doc # pPrintList :: PrettyLevel -> [FileAlreadyExistsError] -> Doc # | |
data TarDirDoesNotExist Source #
Constructors
| TarDirDoesNotExist TarDir |
Instances
| Show TarDirDoesNotExist Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> TarDirDoesNotExist -> ShowS # show :: TarDirDoesNotExist -> String # showList :: [TarDirDoesNotExist] -> ShowS # | |
| HFErrorProject TarDirDoesNotExist Source # | |
Defined in GHCup.Errors | |
| Pretty TarDirDoesNotExist Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> TarDirDoesNotExist -> Doc # pPrint :: TarDirDoesNotExist -> Doc # pPrintList :: PrettyLevel -> [TarDirDoesNotExist] -> Doc # | |
data DigestError Source #
File digest verification failed.
Constructors
| DigestError FilePath Text Text |
Instances
| Show DigestError Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> DigestError -> ShowS # show :: DigestError -> String # showList :: [DigestError] -> ShowS # | |
| HFErrorProject DigestError Source # | |
Defined in GHCup.Errors | |
| Pretty DigestError Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> DigestError -> Doc # pPrint :: DigestError -> Doc # pPrintList :: PrettyLevel -> [DigestError] -> Doc # | |
File PGP verification failed.
Constructors
| forall xs.(ToVariantMaybe DownloadFailed xs, PopVariant DownloadFailed xs, Show (V xs), Pretty (V xs)) => GPGError (V xs) |
Instances
| Show GPGError Source # | |
| HFErrorProject GPGError Source # | |
| Pretty GPGError Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> GPGError -> Doc # pPrintList :: PrettyLevel -> [GPGError] -> Doc # | |
data HTTPStatusError Source #
Unexpected HTTP status.
Constructors
| HTTPStatusError Int (Map (CI ByteString) ByteString) |
Instances
| Show HTTPStatusError Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> HTTPStatusError -> ShowS # show :: HTTPStatusError -> String # showList :: [HTTPStatusError] -> ShowS # | |
| HFErrorProject HTTPStatusError Source # | |
Defined in GHCup.Errors | |
| Pretty HTTPStatusError Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> HTTPStatusError -> Doc # pPrint :: HTTPStatusError -> Doc # pPrintList :: PrettyLevel -> [HTTPStatusError] -> Doc # | |
data MalformedHeaders Source #
Malformed headers.
Constructors
| MalformedHeaders Text |
Instances
| Show MalformedHeaders Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> MalformedHeaders -> ShowS # show :: MalformedHeaders -> String # showList :: [MalformedHeaders] -> ShowS # | |
| HFErrorProject MalformedHeaders Source # | |
Defined in GHCup.Errors | |
| Pretty MalformedHeaders Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> MalformedHeaders -> Doc # pPrint :: MalformedHeaders -> Doc # pPrintList :: PrettyLevel -> [MalformedHeaders] -> Doc # | |
data HTTPNotModified Source #
Unexpected HTTP status.
Constructors
| HTTPNotModified Text |
Instances
| Show HTTPNotModified Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> HTTPNotModified -> ShowS # show :: HTTPNotModified -> String # showList :: [HTTPNotModified] -> ShowS # | |
| HFErrorProject HTTPNotModified Source # | |
Defined in GHCup.Errors | |
| Pretty HTTPNotModified Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> HTTPNotModified -> Doc # pPrint :: HTTPNotModified -> Doc # pPrintList :: PrettyLevel -> [HTTPNotModified] -> Doc # | |
data NoLocationHeader Source #
The Location header was expected during a 3xx redirect, but not found.
Constructors
| NoLocationHeader |
Instances
| Show NoLocationHeader Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> NoLocationHeader -> ShowS # show :: NoLocationHeader -> String # showList :: [NoLocationHeader] -> ShowS # | |
| HFErrorProject NoLocationHeader Source # | |
Defined in GHCup.Errors | |
| Pretty NoLocationHeader Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> NoLocationHeader -> Doc # pPrint :: NoLocationHeader -> Doc # pPrintList :: PrettyLevel -> [NoLocationHeader] -> Doc # | |
data TooManyRedirs Source #
Too many redirects.
Constructors
| TooManyRedirs |
Instances
| Show TooManyRedirs Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> TooManyRedirs -> ShowS # show :: TooManyRedirs -> String # showList :: [TooManyRedirs] -> ShowS # | |
| HFErrorProject TooManyRedirs Source # | |
Defined in GHCup.Errors | |
| Pretty TooManyRedirs Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> TooManyRedirs -> Doc # pPrint :: TooManyRedirs -> Doc # pPrintList :: PrettyLevel -> [TooManyRedirs] -> Doc # | |
data PatchFailed Source #
A patch could not be applied.
Constructors
| PatchFailed |
Instances
| Show PatchFailed Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> PatchFailed -> ShowS # show :: PatchFailed -> String # showList :: [PatchFailed] -> ShowS # | |
| HFErrorProject PatchFailed Source # | |
Defined in GHCup.Errors | |
| Pretty PatchFailed Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> PatchFailed -> Doc # pPrint :: PatchFailed -> Doc # pPrintList :: PrettyLevel -> [PatchFailed] -> Doc # | |
data NoToolRequirements Source #
The tool requirements could not be found.
Constructors
| NoToolRequirements |
Instances
| Show NoToolRequirements Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> NoToolRequirements -> ShowS # show :: NoToolRequirements -> String # showList :: [NoToolRequirements] -> ShowS # | |
| HFErrorProject NoToolRequirements Source # | |
Defined in GHCup.Errors | |
| Pretty NoToolRequirements Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> NoToolRequirements -> Doc # pPrint :: NoToolRequirements -> Doc # pPrintList :: PrettyLevel -> [NoToolRequirements] -> Doc # | |
data InvalidBuildConfig Source #
Constructors
| InvalidBuildConfig Text |
Instances
| Show InvalidBuildConfig Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> InvalidBuildConfig -> ShowS # show :: InvalidBuildConfig -> String # showList :: [InvalidBuildConfig] -> ShowS # | |
| HFErrorProject InvalidBuildConfig Source # | |
Defined in GHCup.Errors | |
| Pretty InvalidBuildConfig Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> InvalidBuildConfig -> Doc # pPrint :: InvalidBuildConfig -> Doc # pPrintList :: PrettyLevel -> [InvalidBuildConfig] -> Doc # | |
data NoToolVersionSet Source #
Constructors
| NoToolVersionSet Tool |
Instances
| Show NoToolVersionSet Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> NoToolVersionSet -> ShowS # show :: NoToolVersionSet -> String # showList :: [NoToolVersionSet] -> ShowS # | |
| HFErrorProject NoToolVersionSet Source # | |
Defined in GHCup.Errors | |
| Pretty NoToolVersionSet Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> NoToolVersionSet -> Doc # pPrint :: NoToolVersionSet -> Doc # pPrintList :: PrettyLevel -> [NoToolVersionSet] -> Doc # | |
Constructors
| NoNetwork |
Instances
| Show NoNetwork Source # | |
| HFErrorProject NoNetwork Source # | |
| Pretty NoNetwork Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> NoNetwork -> Doc # pPrintList :: PrettyLevel -> [NoNetwork] -> Doc # | |
data HadrianNotFound Source #
Constructors
| HadrianNotFound |
Instances
| Show HadrianNotFound Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> HadrianNotFound -> ShowS # show :: HadrianNotFound -> String # showList :: [HadrianNotFound] -> ShowS # | |
| HFErrorProject HadrianNotFound Source # | |
Defined in GHCup.Errors | |
| Pretty HadrianNotFound Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> HadrianNotFound -> Doc # pPrint :: HadrianNotFound -> Doc # pPrintList :: PrettyLevel -> [HadrianNotFound] -> Doc # | |
data ToolShadowed Source #
Constructors
| ToolShadowed Tool FilePath FilePath Version |
Instances
| Show ToolShadowed Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> ToolShadowed -> ShowS # show :: ToolShadowed -> String # showList :: [ToolShadowed] -> ShowS # | |
| HFErrorProject ToolShadowed Source # | |
Defined in GHCup.Errors | |
| Pretty ToolShadowed Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> ToolShadowed -> Doc # pPrint :: ToolShadowed -> Doc # pPrintList :: PrettyLevel -> [ToolShadowed] -> Doc # | |
data ContentLengthError Source #
File content length verification failed.
Instances
| Exception ContentLengthError Source # | |
Defined in GHCup.Errors Methods toException :: ContentLengthError -> SomeException # fromException :: SomeException -> Maybe ContentLengthError # | |
| Show ContentLengthError Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> ContentLengthError -> ShowS # show :: ContentLengthError -> String # showList :: [ContentLengthError] -> ShowS # | |
| HFErrorProject ContentLengthError Source # | |
Defined in GHCup.Errors | |
| Pretty ContentLengthError Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> ContentLengthError -> Doc # pPrint :: ContentLengthError -> Doc # pPrintList :: PrettyLevel -> [ContentLengthError] -> Doc # | |
data DuplicateReleaseChannel Source #
Constructors
| DuplicateReleaseChannel NewURLSource |
Instances
| Show DuplicateReleaseChannel Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> DuplicateReleaseChannel -> ShowS # show :: DuplicateReleaseChannel -> String # showList :: [DuplicateReleaseChannel] -> ShowS # | |
| HFErrorProject DuplicateReleaseChannel Source # | |
Defined in GHCup.Errors | |
| Pretty DuplicateReleaseChannel Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> DuplicateReleaseChannel -> Doc # pPrint :: DuplicateReleaseChannel -> Doc # pPrintList :: PrettyLevel -> [DuplicateReleaseChannel] -> Doc # | |
data UnsupportedSetupCombo Source #
Constructors
| UnsupportedSetupCombo Architecture Platform |
Instances
| Show UnsupportedSetupCombo Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> UnsupportedSetupCombo -> ShowS # show :: UnsupportedSetupCombo -> String # showList :: [UnsupportedSetupCombo] -> ShowS # | |
| HFErrorProject UnsupportedSetupCombo Source # | |
Defined in GHCup.Errors | |
| Pretty UnsupportedSetupCombo Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> UnsupportedSetupCombo -> Doc # pPrint :: UnsupportedSetupCombo -> Doc # pPrintList :: PrettyLevel -> [UnsupportedSetupCombo] -> Doc # | |
data DownloadFailed Source #
A download failed. The underlying error is encapsulated.
Constructors
| forall xs.(HFErrorProject (V xs), ToVariantMaybe DownloadFailed xs, PopVariant DownloadFailed xs, Show (V xs), Pretty (V xs)) => DownloadFailed (V xs) |
Instances
| Show DownloadFailed Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> DownloadFailed -> ShowS # show :: DownloadFailed -> String # showList :: [DownloadFailed] -> ShowS # | |
| HFErrorProject DownloadFailed Source # | |
Defined in GHCup.Errors | |
| Pretty DownloadFailed Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> DownloadFailed -> Doc # pPrint :: DownloadFailed -> Doc # pPrintList :: PrettyLevel -> [DownloadFailed] -> Doc # | |
data InstallSetError Source #
Constructors
| forall xs1 xs2.(Show (V xs1), Pretty (V xs1), HFErrorProject (V xs1), Show (V xs2), Pretty (V xs2), HFErrorProject (V xs2)) => InstallSetError (V xs1) (V xs2) |
Instances
| Show InstallSetError Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> InstallSetError -> ShowS # show :: InstallSetError -> String # showList :: [InstallSetError] -> ShowS # | |
| HFErrorProject InstallSetError Source # | |
Defined in GHCup.Errors | |
| Pretty InstallSetError Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> InstallSetError -> Doc # pPrint :: InstallSetError -> Doc # pPrintList :: PrettyLevel -> [InstallSetError] -> Doc # | |
data TestFailed Source #
A test failed.
Constructors
| forall es.(ToVariantMaybe TestFailed es, PopVariant TestFailed es, Pretty (V es), Show (V es), HFErrorProject (V es)) => TestFailed FilePath (V es) |
Instances
| Show TestFailed Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> TestFailed -> ShowS # show :: TestFailed -> String # showList :: [TestFailed] -> ShowS # | |
| HFErrorProject TestFailed Source # | |
Defined in GHCup.Errors | |
| Pretty TestFailed Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> TestFailed -> Doc # pPrint :: TestFailed -> Doc # pPrintList :: PrettyLevel -> [TestFailed] -> Doc # | |
data BuildFailed Source #
A build failed.
Constructors
| forall es.(ToVariantMaybe BuildFailed es, PopVariant BuildFailed es, Pretty (V es), Show (V es), HFErrorProject (V es)) => BuildFailed FilePath (V es) |
Instances
| Show BuildFailed Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> BuildFailed -> ShowS # show :: BuildFailed -> String # showList :: [BuildFailed] -> ShowS # | |
| HFErrorProject BuildFailed Source # | |
Defined in GHCup.Errors | |
| Pretty BuildFailed Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> BuildFailed -> Doc # pPrint :: BuildFailed -> Doc # pPrintList :: PrettyLevel -> [BuildFailed] -> Doc # | |
data GHCupSetError Source #
Setting the current GHC version failed.
Constructors
| forall es.(ToVariantMaybe GHCupSetError es, PopVariant GHCupSetError es, Show (V es), Pretty (V es), HFErrorProject (V es)) => GHCupSetError (V es) |
Instances
| Show GHCupSetError Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> GHCupSetError -> ShowS # show :: GHCupSetError -> String # showList :: [GHCupSetError] -> ShowS # | |
| HFErrorProject GHCupSetError Source # | |
Defined in GHCup.Errors | |
| Pretty GHCupSetError Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> GHCupSetError -> Doc # pPrint :: GHCupSetError -> Doc # pPrintList :: PrettyLevel -> [GHCupSetError] -> Doc # | |
data StackPlatformDetectError Source #
Executing stacks platform detection failed.
Constructors
| forall es.(ToVariantMaybe StackPlatformDetectError es, PopVariant StackPlatformDetectError es, Show (V es), Pretty (V es), HFErrorProject (V es)) => StackPlatformDetectError (V es) |
Instances
| Show StackPlatformDetectError Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> StackPlatformDetectError -> ShowS # show :: StackPlatformDetectError -> String # showList :: [StackPlatformDetectError] -> ShowS # | |
| HFErrorProject StackPlatformDetectError Source # | |
Defined in GHCup.Errors | |
| Pretty StackPlatformDetectError Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> StackPlatformDetectError -> Doc # pPrint :: StackPlatformDetectError -> Doc # pPrintList :: PrettyLevel -> [StackPlatformDetectError] -> Doc # | |
data ParseError Source #
Parsing failed.
Constructors
| ParseError String |
Instances
| Exception ParseError Source # | |
Defined in GHCup.Errors Methods toException :: ParseError -> SomeException # fromException :: SomeException -> Maybe ParseError # displayException :: ParseError -> String # | |
| Show ParseError Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> ParseError -> ShowS # show :: ParseError -> String # showList :: [ParseError] -> ShowS # | |
| HFErrorProject ParseError Source # | |
Defined in GHCup.Errors | |
| Pretty ParseError Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> ParseError -> Doc # pPrint :: ParseError -> Doc # pPrintList :: PrettyLevel -> [ParseError] -> Doc # | |
data UnexpectedListLength Source #
Constructors
| UnexpectedListLength String |
Instances
| Exception UnexpectedListLength Source # | |
Defined in GHCup.Errors Methods toException :: UnexpectedListLength -> SomeException # fromException :: SomeException -> Maybe UnexpectedListLength # | |
| Show UnexpectedListLength Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> UnexpectedListLength -> ShowS # show :: UnexpectedListLength -> String # showList :: [UnexpectedListLength] -> ShowS # | |
| HFErrorProject UnexpectedListLength Source # | |
Defined in GHCup.Errors | |
| Pretty UnexpectedListLength Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> UnexpectedListLength -> Doc # pPrint :: UnexpectedListLength -> Doc # pPrintList :: PrettyLevel -> [UnexpectedListLength] -> Doc # | |
Instances
| Exception NoUrlBase Source # | |
Defined in GHCup.Errors Methods toException :: NoUrlBase -> SomeException # fromException :: SomeException -> Maybe NoUrlBase # displayException :: NoUrlBase -> String # | |
| Show NoUrlBase Source # | |
| HFErrorProject NoUrlBase Source # | |
| Pretty NoUrlBase Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> NoUrlBase -> Doc # pPrintList :: PrettyLevel -> [NoUrlBase] -> Doc # | |
data DigestMissing Source #
Constructors
| DigestMissing URI |
Instances
| Exception DigestMissing Source # | |
Defined in GHCup.Errors Methods toException :: DigestMissing -> SomeException # fromException :: SomeException -> Maybe DigestMissing # displayException :: DigestMissing -> String # | |
| Show DigestMissing Source # | |
Defined in GHCup.Errors Methods showsPrec :: Int -> DigestMissing -> ShowS # show :: DigestMissing -> String # showList :: [DigestMissing] -> ShowS # | |
| HFErrorProject DigestMissing Source # | |
Defined in GHCup.Errors | |
| Pretty DigestMissing Source # | |
Defined in GHCup.Errors Methods pPrintPrec :: PrettyLevel -> Rational -> DigestMissing -> Doc # pPrint :: DigestMissing -> Doc # pPrintList :: PrettyLevel -> [DigestMissing] -> Doc # | |